@@ -284,13 +284,25 @@ GdkPixbuf *gdk_pixbuf_new_subpixbuf (GdkPixbuf *src_pixbuf,
 
 /* Simple loading */
 
-#ifndef __GTK_DOC_IGNORE__
 #ifdef G_OS_WIN32
-/* DLL ABI stability hack. */
-#define gdk_pixbuf_new_from_file gdk_pixbuf_new_from_file_utf8
-#define gdk_pixbuf_new_from_file_at_size gdk_pixbuf_new_from_file_at_size_utf8
-#define gdk_pixbuf_new_from_file_at_scale gdk_pixbuf_new_from_file_at_scale_utf8
-#endif
+/* In previous versions these _utf8 variants where exported and linked to
+ * by default. Export them here for ABI (and gi API) compat.
+ */
+
+GDK_PIXBUF_AVAILABLE_IN_ALL
+GdkPixbuf *gdk_pixbuf_new_from_file_utf8 (const char *filename,
+                                          GError    **error);
+GDK_PIXBUF_AVAILABLE_IN_2_4
+GdkPixbuf *gdk_pixbuf_new_from_file_at_size_utf8 (const char *filename,
+                                                  int         width,
+                                                  int         height,
+                                                  GError    **error);
+GDK_PIXBUF_AVAILABLE_IN_2_6
+GdkPixbuf *gdk_pixbuf_new_from_file_at_scale_utf8 (const char *filename,
+                                                   int         width,
+                                                   int         height,
+                                                   gboolean    preserve_aspect_ratio,
+                                                   GError    **error);
 #endif
 
 GDK_PIXBUF_AVAILABLE_IN_ALL
@@ -357,7 +369,6 @@ void       gdk_pixbuf_fill              (GdkPixbuf    *pixbuf,
 #ifdef G_OS_WIN32
 /* DLL ABI stability hack. */
 #define gdk_pixbuf_save gdk_pixbuf_save_utf8
-#define gdk_pixbuf_savev gdk_pixbuf_savev_utf8
 #endif
 #endif
 
@@ -376,6 +387,16 @@ gboolean gdk_pixbuf_savev          (GdkPixbuf  *pixbuf,
                                     char      **option_values,
                                     GError    **error);
 
+#ifdef G_OS_WIN32
+GDK_PIXBUF_AVAILABLE_IN_ALL
+gboolean gdk_pixbuf_savev_utf8     (GdkPixbuf  *pixbuf,
+                                    const char *filename,
+                                    const char *type,
+                                    char      **option_keys,
+                                    char      **option_values,
+                                    GError    **error);
+#endif
+
 /* Saving to a callback function */
 
 
